.. title:: bfieldtools


.. raw:: html

  <div class="col-xs-12 col-md-9 jumbotron align-center">
    <div class="col-xs-12 nopad">
      <img src="_static/logo_simple_w_name.svg" style="max-width: 1000px; width: 100%" alt="bfieldtools">
      <p>
      Open-source Python software for magnetic field modeling
      </p>
    </div>
    <div class="col-xs-12 nopad">
    

.. carousel
.. include:: carousel.inc

.. raw:: html

    </div>
  </div>

|

.. quick_links box (with spacer)
.. raw:: html

  <div class="col-xs-12 col-sm-6 col-md-3">
    <div class="panel panel-default">
      <div class="panel-heading"><h3 class="panel-title">Quick links</h3></div>
      <div class="panel-body">
        <ul>
        <li><a href="https://github.com/bfieldtools/bfieldtools">GitHub</a></li>
        <li><a href="authors.html">Authors</a></li>
        <li><a href="overview.html#contributing">Contribute</a></li>
        <li><a href="overview.html#citing-bfieldtools">Cite</a></li>
      </div>
    </div>
  </div>

  
.. toctree::
   :hidden: 
   :maxdepth: 3
   :caption: Contents:

   overview

   installation
   
   literature
   
   auto_examples/index
   
   api_reference
